==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEQUALIFICATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour EMPLOYEEQUALIFICATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEQUALIFICATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEQUALIFICATIONID_Type", propOrder = {
    "employeeid",
    "qualificationid",
    "startdate"
})
public class EMPLOYEEQUALIFICATIONID_Type {

    @XmlElement(name = "EMPLOYEEID", required = true)
    protected Employee_Type employeeid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Obtient la valeur de la propriété employeeid.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getEMPLOYEEID() {
        return employeeid;
    }

    /**
     * Définit la valeur de la propriété employeeid.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setEMPLOYEEID(Employee_Type value) {
        this.employeeid = value;
    }

    /**
     * Obtient la valeur de la propriété qualificationid.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Définit la valeur de la propriété qualificationid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEQUALIFICATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for EMPLOYEEQUALIFICATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEQUALIFICATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEQUALIFICATIONID_Type", propOrder = {
    "employeeid",
    "qualificationid",
    "startdate"
})
public class EMPLOYEEQUALIFICATIONID_Type {

    @XmlElement(name = "EMPLOYEEID", required = true)
    protected Employee_Type employeeid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the employeeid property.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getEMPLOYEEID() {
        return employeeid;
    }

    /**
     * Sets the value of the employeeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setEMPLOYEEID(Employee_Type value) {
        this.employeeid = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Sets the value of the qualificationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}
